@@ -2,4 +2,4 @@
 firebasin is a Python implementation of the Firebase API
 '''
 
-from .async import Firebase     # importing async
+from .async import Firebase
